from distutils.core import setup


setup(
        name             ='nester2021',
        version          ='1.0.0',
        py_modules       =['nester2021'],
        author           ='jiangjunjin',
        author_email     ='jiangjunjin@vip.qq.com',
        url              ='http://www.qq.com',
        description      ='A simple printer of nested lists',
    )
